from distutils.core import setup
setup(
        name = 'nhlpy',
        packages = ['nhlpy'],
        version = '0.2.1',
        description = 'An easy to use NHL API wrapper',
        author = 'Alexander Delgado',
        author_email = 'jobehico@gmail.com',
        url = 'https://github.com/0xalexdelgado/nhlpy',
        download_url = 'https://github.com/0xalexdelgado/nhlpy/archive/0.2.tar.gz',
        keywords = ['hockey', 'API', 'NHL', 'wrapper', 'api', 'nhlpy', 'statistics'],
        classifiers = [],
        )

